# Warning: this package is synchronized with Fedora!

%global libmajor 0
%global girapi 1.0
%global girlib %mklibname %{name}-gir %{girapi}
%global libname %mklibname %{name} %{libmajor}
%global devname %mklibname %{name} -d

# Minimum dependent components
%global bubblewrap_version 0.1.8
%global ostree_version 2017.7

%{?!_pkgdocdir:%global _pkgdocdir %{_docdir}/%{name}}

Name:           flatpak
Version:        0.9.6
Release:        %mkrel 2
Summary:        Application deployment framework for desktop apps

Group:          System/Packaging
License:        LGPLv2+
URL:            https://flatpak.org/
Source0:        https://github.com/flatpak/flatpak/releases/download/%{version}/%{name}-%{version}.tar.xz

BuildRequires:  pkgconfig(fuse)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libarchive) >= 2.8.0
BuildRequires:  pkgconfig(libelf) >= 0.8.12
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(libxml-2.0) >= 2.4
BuildRequires:  pkgconfig(ostree-1) >= %{ostree_version}
BuildRequires:  pkgconfig(polkit-gobject-1)
BuildRequires:  pkgconfig(libseccomp)
BuildRequires:  pkgconfig(xau)
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  gobject-introspection-devel >= 1.40.0
BuildRequires:  docbook-dtds
BuildRequires:  docbook-style-xsl
BuildRequires:  gpgme-devel
BuildRequires:  intltool
BuildRequires:  libattr-devel
BuildRequires:  libcap-devel
BuildRequires:  libdwarf-devel
BuildRequires:  systemd-devel
BuildRequires:  xsltproc
BuildRequires:  xmlto
BuildRequires:  bubblewrap >= %{bubblewrap_version}

# Crashes with older kernels (the bug being introduced in 4.0.2), without the
# upstream fixes in this version.
Requires:       kernel >= 4.1.0

# Needed for the document portal.
Requires:       fuse

# Needed for confinement
Requires:       bubblewrap%{?_isa} >= %{bubblewrap_version}
Requires:       ostree%{?_isa} >= %{ostree_version}

# Required to ensure flatpak functions
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Requires:       %{girlib}%{?_isa} = %{version}-%{release}

%description
flatpak is a system for building, distributing and running sandboxed desktop
applications on Linux. See https://wiki.gnome.org/Projects/SandboxedApps for
more information.

%package builder
Summary:        Build helper for %{name}
Group:          System/Packaging
License:        LGPLv2+
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       bzr
Requires:       git-core
Requires:       patch
Requires:       binutils
Requires:       tar
Requires:       unzip
# For debuginfo
Requires:       elfutils

%description builder
flatpak-builder is a tool that makes it easy to build applications and their
dependencies by automating the configure && make && make install steps.

%package -n %{devname}
Summary:        Development files for %{name}
Group:          Development/C
License:        LGPLv2+
Provides:       %{name}-devel = %{version}-%{release}
Provides:       %{name}-devel%{?_isa} = %{version}-%{release}
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Requires:       %{girlib}%{?_isa} = %{version}-%{release}

%description -n %{devname}
This package contains the pkg-config file and development headers for %{name}.

%package -n %{libname}
Summary:        Libraries for %{name}
Group:          System/Libraries
License:        LGPLv2+
Requires:       bubblewrap%{?_isa} >= %{bubblewrap_version}
Requires:       ostree%{?_isa} >= %{ostree_version}

%description -n %{libname}
This package contains libflatpak.

%package -n %{girlib}
Summary:        GObject Introspection Libraries for %{name}
Group:          System/Libraries
License:        LGPLv2+
Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description -n %{girlib}
This package contains libflatpak GObject libraries.


%prep
%autosetup -p1

%build
(if ! test -x configure; then NOCONFIGURE=1 ./autogen.sh; CONFIGFLAGS=--enable-gtk-doc; fi;
 # User namespace support is sufficient.
  %configure2_5x --with-dwarf-header=%{_includedir}/libdwarf --with-priv-mode=none \
                 --with-system-bubblewrap --enable-docbook-docs $CONFIGFLAGS)

%make_build V=1


%install
%make_install
# The system repo is not installed by the flatpak build system.
install -d %{buildroot}%{_localstatedir}/lib/flatpak
install -d %{buildroot}%{_sysconfdir}/flatpak/remotes.d
rm -f %{buildroot}%{_libdir}/libflatpak.la


%find_lang %{name}

%post
# Create an (empty) system-wide repo.
flatpak remote-list --system &> /dev/null || :


%files -f %{name}.lang
%license COPYING
%doc NEWS README.md
%doc %{_pkgdocdir}
%{_bindir}/flatpak
%{_bindir}/flatpak-bisect
%{_datadir}/bash-completion
%{_datadir}/dbus-1/interfaces/org.freedesktop.Flatpak.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.portal.Documents.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.impl.portal.PermissionStore.xml
%{_datadir}/dbus-1/services/org.freedesktop.Flatpak.service
%{_datadir}/dbus-1/services/org.freedesktop.impl.portal.PermissionStore.service
%{_datadir}/dbus-1/services/org.freedesktop.portal.Documents.service
%{_datadir}/dbus-1/system-services/org.freedesktop.Flatpak.SystemHelper.service
# Co-own directory.
%{_datadir}/gdm/env.d
%{_datadir}/%{name}
%{_datadir}/polkit-1/actions/org.freedesktop.Flatpak.policy
%{_datadir}/polkit-1/rules.d/org.freedesktop.Flatpak.rules
%{_libexecdir}/flatpak-dbus-proxy
%{_libexecdir}/flatpak-session-helper
%{_libexecdir}/flatpak-system-helper
%{_libexecdir}/xdg-document-portal
%{_libexecdir}/xdg-permission-store
%dir %{_localstatedir}/lib/flatpak
%dir %{_sysconfdir}/flatpak/remotes.d
%{_mandir}/man1/%{name}*.1*
%{_mandir}/man5/%{name}-metadata.5*
%{_mandir}/man5/%{name}-flatpakref.5*
%{_mandir}/man5/%{name}-flatpakrepo.5*
%{_mandir}/man5/%{name}-installation.5*
%{_mandir}/man5/%{name}-manifest.5*
%{_mandir}/man5/%{name}-remote.5*
%exclude %{_mandir}/man1/flatpak-builder.1*
%{_sysconfdir}/dbus-1/system.d/org.freedesktop.Flatpak.SystemHelper.conf
%{_sysconfdir}/profile.d/flatpak.sh
%{_unitdir}/flatpak-system-helper.service
%{_userunitdir}/flatpak-session-helper.service
%{_userunitdir}/xdg-document-portal.service
%{_userunitdir}/xdg-permission-store.service
# Co-own directory.
%{_userunitdir}/dbus.service.d


%files builder
%{_bindir}/flatpak-builder
%{_mandir}/man1/flatpak-builder.1*

%files -n %{devname}
%{_datadir}/gir-1.0/Flatpak-%{girapi}.gir
%{_datadir}/gtk-doc/
%{_includedir}/%{name}/
%{_libdir}/libflatpak.so
%{_libdir}/pkgconfig/%{name}.pc

%files -n %{libname}
%license COPYING
%{_libdir}/libflatpak.so.%{libmajor}
%{_libdir}/libflatpak.so.%{libmajor}.*

%files -n %{girlib}
%{_libdir}/girepository-1.0/Flatpak-%{girapi}.typelib


%changelog
* Sat Jun 24 2017 ngompa <ngompa> 0.9.6-2.mga6
+ Revision: 1108264
- Update to 0.9.6

* Fri May 26 2017 akien <akien> 0.9.4-2.mga6
+ Revision: 1104770
- Rebuild for armv5tl (buildsystem issue)

* Fri May 26 2017 ngompa <ngompa> 0.9.4-1.mga6
+ Revision: 1104757
- Update to 0.9.4

* Thu Apr 27 2017 ngompa <ngompa> 0.9.3-1.mga6
+ Revision: 1097788
- Update to 0.9.3

* Tue Mar 21 2017 ovitters <ovitters> 0.9.1-1.mga6
+ Revision: 1094194
- new version 0.9.1

* Thu Mar 16 2017 ngompa <ngompa> 0.8.4-1.mga6
+ Revision: 1093163
- Update to 0.8.4

* Fri Feb 17 2017 ngompa <ngompa> 0.8.3-1.mga6
+ Revision: 1086571
- Update to 0.8.3

* Mon Jan 30 2017 ngompa <ngompa> 0.8.2-1.mga6
+ Revision: 1084179
- Upgrade to 0.8.2 (Fixes mga#20208)

* Mon Jan 16 2017 ngompa <ngompa> 0.8.0-1.mga6
+ Revision: 1082044
- Upgrade to v0.8.0

* Tue Dec 13 2016 akien <akien> 0.6.14-2.mga6
+ Revision: 1074451
- Rebuild for updated ostree

* Tue Dec 13 2016 ngompa <ngompa> 0.6.14-1.mga6
+ Revision: 1074438
- Upgrade to 0.6.14

* Sat Nov 12 2016 ngompa <ngompa> 0.6.13-2.mga6
+ Revision: 1066784
- Add empty /etc/flatpak/remotes.d

* Wed Oct 26 2016 ngompa <ngompa> 0.6.13-1.mga6
+ Revision: 1063586
- Upgrade to 0.6.13

* Tue Oct 11 2016 pterjan <pterjan> 0.6.12-2.mga6
+ Revision: 1060194
- Rebuild some recently rejected packages, some were due to a bug in the build system

* Tue Oct 11 2016 ngompa <ngompa> 0.6.12-1.mga6
+ Revision: 1060122
- Upgrade to 0.6.12

* Mon Sep 26 2016 tv <tv> 0.6.11-2.mga6
+ Revision: 1056877
- rebuild with fixed rpm-mageia-setup for missing generating typelib() requires (mga#19454)

* Sun Sep 25 2016 ngompa <ngompa> 0.6.11-1.mga6
+ Revision: 1055953
- Upgrade to 0.6.11
- Set minimum ostree and bubblewrap versions

* Thu Aug 25 2016 ngompa <ngompa> 0.6.9-1.mga6
+ Revision: 1048912
- Update to 0.6.9
- Drop unneeded Obsoletes

* Mon Aug 01 2016 ngompa <ngompa> 0.6.8-1.mga6
+ Revision: 1044203
- Bump libostree BR
- Update to 0.6.8 and unbundle bubblewrap from flatpak

* Sat Jul 02 2016 ngompa <ngompa> 0.6.7-1.mga6
+ Revision: 1038364
- Update to 0.6.7

* Sat Jun 25 2016 ngompa <ngompa> 0.6.6-1.mga6
+ Revision: 1037471
- Upgrade to 0.6.6

* Wed Jun 22 2016 ngompa <ngompa> 0.6.5-2.mga6
+ Revision: 1037222
- Add enforced requires for flatpak libraries

* Tue Jun 21 2016 ngompa <ngompa> 0.6.5-1.mga6
+ Revision: 1037015
- Upgrade to flatpak 0.6.5
- Rename xdg-app to flatpak

* Wed Jan 20 2016 daviddavid <daviddavid> 0.4.4-2.mga6
+ Revision: 926028
- switch to %%configure2_5x to fix build

* Thu Oct 08 2015 ovitters <ovitters> 0.4.4-1.mga6
+ Revision: 887873
- from fedora

